Cave Story: Tweaked ~ Manual

Exploration/action game
Cave Story
(Tweaked)

Screens shown may vary
from final release

- [Introduction]
- [Display]
- [Items]
- [Options]
- [Tweaks]

## Introduction

Cave Story: Tweaked is a jumping-and-shooting action game.
Explore the caves until you reach the ending.
You can also save your game and continue from where you left off.

#### Compatible Systems

- Windows 7/8/10
- Linux
- Mac OS
- Nintendo Wii U
- Nintendo 3DS
- RISC OS

#### Features

- Gamepad support
- Choose between full-screen and windowed mode, and resolution
- Choose in-game font
- Choose between 50 FPS (original) or 60 FPS (Cave Story+) framerate

## In-game Display

This is a typical gameplay screen.

The main character (you).

An enemy. There are many others as well.

The current weapon and the number of shots left.
The top meter shows your Weapon Energy.
The bottom meter is your life bar.

## Items

#### Field Items

| Disk | Saves your game.
| Energy | Collect these to level-up your weapon.
| Life | Restores your health.
| Missile | Restores your missile ammunition.
| Server | Fully restores your health and ammunition.
| Life Capsule | Increases your maximum health.
| Treasure Chest | All kinds of goodies lurk inside.

(There are many others.)

#### Event Items

| Map System | Displays a map of the current stage.
| Silver Locket | Someone's pendant.
| Arthur's Key | A key to open a door somewhere.

(For more details, try the game.)

## Options

The Options Menu allows you to adjust the game's functions. You can change the font the game displays, the window size, and change your control method and mapping. Please visit the menu for more information.

## Tweaks

The Tweaks Menu allows you to modify the game at will. This includes options such as modifying game speed and boss HP, giing yourself items, or disabling EXP drops. I hope this menu allows players of all kinds to enjoy the game.

#### Tweaks List

Damage Received | Modifies how much damage your character takes when hit.
Boss Health | Changes how much health bosses have when you fight them.
Autofire | Allows you to hold or just press a button to shoot rapidly.
Infinite Ammo | Weapons that use Ammo (such as Missiles) will never run out.
Default Booster | Lets you equip yourself with a Booster to fly thru stages.
Infinite Booster | Booster Fuel never runs out.
Grace Jumps | Allows you to jump shortly after running off a ledge.
No Exp Drops | Disables all sources of Weapon Energy.
Mirror Mode | Flips the game horizontally.
Game Speed | Slow down or speed up the game.